==> misfortune-0.1.2.1-154-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-3w7MndkZZgg8P6jST0D8O7
key:                  misfortune-0.1.2.1-3w7MndkZZgg8P6jST0D8O7
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  4219d697d4523da6cbd35811f6888599
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-3w7MndkZZgg8P6jST0D8O7
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT directory-1.3.7.1
    filepath-1.4.2.2 knob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
    random-1.2.1.3-9Bk1Rk8uHFTJVqAMIpxjnc
    random-fu-0.3.0.1-9v6y5i9RtgI3ekiL4dJfsS text-2.0.2
    utf8-string-1.0.2-LtGEIYPp5RR87I6rMd4Fpy
    vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> misfortune-0.1.2.1-155-x86_64.pkg.tar.zst: usr/share/haskell/register/misfortune.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 misfortune
version:              0.1.2.1
visibility:           public
id:                   misfortune-0.1.2.1-FJaBvOaWBzrAmTEXvBQ5yk
key:                  misfortune-0.1.2.1-FJaBvOaWBzrAmTEXvBQ5yk
license:              MIT
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            experimental
homepage:             https://github.com/ncfavier/misfortune
synopsis:             fortune-mod clone
description:          fortune-mod clone, in library and executable form.
category:             Console, Game
abi:                  af8256aa918e63325a0e7d7e01145d68
exposed:              True
exposed-modules:      Data.Fortune
hidden-modules:
    Data.Fortune.FortuneFile Data.Fortune.Index Data.Fortune.Stats
    Paths_misfortune

import-dirs:          /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/misfortune-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/misfortune
hs-libraries:         HSmisfortune-0.1.2.1-FJaBvOaWBzrAmTEXvBQ5yk
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT directory-1.3.7.1
    filepath-1.4.2.2 knob-0.2.2-HhpH2zzkSI93rWV7pYCvrU
    random-1.2.1.3-Kx84bR0MhuXELN1ev6GdTW
    random-fu-0.3.0.1-GKLgyBYXDsa66lQqXbmbB4 text-2.0.2
    utf8-string-1.0.2-Kx3GnjsHBwcIRYSetT14kb
    vector-0.13.2.0-EQFZws9ZIK8A2ESM3MR23n

haddock-interfaces:   /usr/share/doc/misfortune/html/misfortune.haddock
haddock-html:         /usr/share/doc/misfortune/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
